@@ -4,27 +4,26 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 #include "plasmashell_interface.h"
+#include "display.h"
 #include "global_p.h"
 #include "resource_p.h"
-#include "display.h"
 #include "surface_interface.h"
 
 #include <QTimer>
 
-#include <wayland-server.h>
 #include <wayland-plasma-shell-server-protocol.h>
+#include <wayland-server.h>
 
 namespace KWayland
 {
 namespace Server
 {
-
 class PlasmaShellInterface::Private : public Global::Private
 {
 public:
     Private(PlasmaShellInterface *q, Display *d);
 
-    QList<PlasmaShellSurfaceInterface*> surfaces;
+    QList<PlasmaShellSurfaceInterface *> surfaces;
 
 private:
     static void createSurfaceCallback(wl_client *client, wl_resource *resource, uint32_t id, wl_resource *surface);
@@ -45,12 +44,9 @@ PlasmaShellInterface::Private::Private(PlasmaShellInterface *q, Display *d)
 }
 
 #ifndef K_DOXYGEN
-const struct org_kde_plasma_shell_interface PlasmaShellInterface::Private::s_interface = {
-    createSurfaceCallback
-};
+const struct org_kde_plasma_shell_interface PlasmaShellInterface::Private::s_interface = {createSurfaceCallback};
 #endif
 
-
 class PlasmaShellSurfaceInterface::Private : public Resource::Private
 {
 public:
@@ -81,7 +77,8 @@ private:
     void setRole(uint32_t role);
     void setPanelBehavior(org_kde_plasma_surface_panel_behavior behavior);
 
-    PlasmaShellSurfaceInterface *q_func() {
+    PlasmaShellSurfaceInterface *q_func()
+    {
         return reinterpret_cast<PlasmaShellSurfaceInterface *>(q);
     }
 
@@ -108,54 +105,51 @@ void PlasmaShellInterface::Private::bind(wl_client *client, uint32_t version, ui
 
 void PlasmaShellInterface::Private::createSurfaceCallback(wl_client *client, wl_resource *resource, uint32_t id, wl_resource *surface)
 {
-    auto s = reinterpret_cast<PlasmaShellInterface::Private*>(wl_resource_get_user_data(resource));
+    auto s = reinterpret_cast<PlasmaShellInterface::Private *>(wl_resource_get_user_data(resource));
     s->createSurface(client, wl_resource_get_version(resource), id, SurfaceInterface::get(surface), resource);
 }
 
 void PlasmaShellInterface::Private::createSurface(wl_client *client, uint32_t version, uint32_t id, SurfaceInterface *surface, wl_resource *parentResource)
 {
-    auto it = std::find_if(surfaces.constBegin(), surfaces.constEnd(),
-        [surface](PlasmaShellSurfaceInterface *s) {
-            return surface == s->surface();
-        }
-    );
+    auto it = std::find_if(surfaces.constBegin(), surfaces.constEnd(), [surface](PlasmaShellSurfaceInterface *s) {
+        return surface == s->surface();
+    });
     if (it != surfaces.constEnd()) {
         wl_resource_post_error(surface->resource(), WL_DISPLAY_ERROR_INVALID_OBJECT, "PlasmaShellSurface already created");
         return;
     }
     PlasmaShellSurfaceInterface *shellSurface = new PlasmaShellSurfaceInterface(q, surface, parentResource);
     surfaces << shellSurface;
-    QObject::connect(shellSurface, &PlasmaShellSurfaceInterface::destroyed, q,
-        [this, shellSurface] {
-            surfaces.removeAll(shellSurface);
-        }
-    );
+    QObject::connect(shellSurface, &PlasmaShellSurfaceInterface::destroyed, q, [this, shellSurface] {
+        surfaces.removeAll(shellSurface);
+    });
     shellSurface->d->create(display->getConnection(client), version, id);
-    emit q->surfaceCreated(shellSurface);
+    Q_EMIT q->surfaceCreated(shellSurface);
 }
 
 /*********************************
  * ShellSurfaceInterface
  *********************************/
-PlasmaShellSurfaceInterface::Private::Private(PlasmaShellSurfaceInterface *q, PlasmaShellInterface *shell, SurfaceInterface *surface, wl_resource *parentResource)
+PlasmaShellSurfaceInterface::Private::Private(PlasmaShellSurfaceInterface *q,
+                                              PlasmaShellInterface *shell,
+                                              SurfaceInterface *surface,
+                                              wl_resource *parentResource)
     : Resource::Private(q, shell, parentResource, &org_kde_plasma_surface_interface, &s_interface)
     , surface(surface)
 {
 }
 
 #ifndef K_DOXYGEN
-const struct org_kde_plasma_surface_interface PlasmaShellSurfaceInterface::Private::s_interface = {
-    resourceDestroyedCallback,
-    setOutputCallback,
-    setPositionCallback,
-    setRoleCallback,
-    setPanelBehaviorCallback,
-    setSkipTaskbarCallback,
-    panelAutoHideHideCallback,
-    panelAutoHideShowCallback,
-    panelTakesFocusCallback,
-    setSkipSwitcherCallback
-};
+const struct org_kde_plasma_surface_interface PlasmaShellSurfaceInterface::Private::s_interface = {resourceDestroyedCallback,
+                                                                                                   setOutputCallback,
+                                                                                                   setPositionCallback,
+                                                                                                   setRoleCallback,
+                                                                                                   setPanelBehaviorCallback,
+                                                                                                   setSkipTaskbarCallback,
+                                                                                                   panelAutoHideHideCallback,
+                                                                                                   panelAutoHideShowCallback,
+                                                                                                   panelTakesFocusCallback,
+                                                                                                   setSkipSwitcherCallback};
 #endif
 
 PlasmaShellSurfaceInterface::PlasmaShellSurfaceInterface(PlasmaShellInterface *shell, SurfaceInterface *parent, wl_resource *parentResource)
@@ -171,19 +165,21 @@ PlasmaShellSurfaceInterface::PlasmaShellSurfaceInterface(PlasmaShellInterface *s
 
 PlasmaShellSurfaceInterface::~PlasmaShellSurfaceInterface() = default;
 
-SurfaceInterface *PlasmaShellSurfaceInterface::surface() const {
+SurfaceInterface *PlasmaShellSurfaceInterface::surface() const
+{
     Q_D();
     return d->surface;
 }
 
-PlasmaShellInterface *PlasmaShellSurfaceInterface::shell() const {
+PlasmaShellInterface *PlasmaShellSurfaceInterface::shell() const
+{
     Q_D();
-    return reinterpret_cast<PlasmaShellInterface*>(d->global);
+    return reinterpret_cast<PlasmaShellInterface *>(d->global);
 }
 
 PlasmaShellSurfaceInterface::Private *PlasmaShellSurfaceInterface::d_func() const
 {
-    return reinterpret_cast<PlasmaShellSurfaceInterface::Private*>(d.data());
+    return reinterpret_cast<PlasmaShellSurfaceInterface::Private *>(d.data());
 }
 
 void PlasmaShellSurfaceInterface::Private::setOutputCallback(wl_client *client, wl_resource *resource, wl_resource *output)
@@ -209,7 +205,7 @@ void PlasmaShellSurfaceInterface::Private::setPosition(const QPoint &globalPos)
     m_positionSet = true;
     m_globalPos = globalPos;
     Q_Q(PlasmaShellSurfaceInterface);
-    emit q->positionChanged();
+    Q_EMIT q->positionChanged();
 }
 
 void PlasmaShellSurfaceInterface::Private::setRoleCallback(wl_client *client, wl_resource *resource, uint32_t role)
@@ -251,7 +247,7 @@ void PlasmaShellSurfaceInterface::Private::setRole(uint32_t role)
     }
     m_role = r;
     Q_Q(PlasmaShellSurfaceInterface);
-    emit q->roleChanged();
+    Q_EMIT q->roleChanged();
 }
 
 void PlasmaShellSurfaceInterface::Private::setPanelBehaviorCallback(wl_client *client, wl_resource *resource, uint32_t flag)
@@ -266,7 +262,7 @@ void PlasmaShellSurfaceInterface::Private::setSkipTaskbarCallback(wl_client *cli
     auto s = cast<Private>(resource);
     Q_ASSERT(client == *s->client);
     s->m_skipTaskbar = (bool)skip;
-    emit s->q_func()->skipTaskbarChanged();
+    Q_EMIT s->q_func()->skipTaskbarChanged();
 }
 
 void PlasmaShellSurfaceInterface::Private::setSkipSwitcherCallback(wl_client *client, wl_resource *resource, uint32_t skip)
@@ -274,7 +270,7 @@ void PlasmaShellSurfaceInterface::Private::setSkipSwitcherCallback(wl_client *cl
     auto s = cast<Private>(resource);
     Q_ASSERT(client == *s->client);
     s->m_skipSwitcher = (bool)skip;
-    emit s->q_func()->skipSwitcherChanged();
+    Q_EMIT s->q_func()->skipSwitcherChanged();
 }
 
 void PlasmaShellSurfaceInterface::Private::panelAutoHideHideCallback(wl_client *client, wl_resource *resource)
@@ -285,7 +281,7 @@ void PlasmaShellSurfaceInterface::Private::panelAutoHideHideCallback(wl_client *
         wl_resource_post_error(s->resource, ORG_KDE_PLASMA_SURFACE_ERROR_PANEL_NOT_AUTO_HIDE, "Not an auto hide panel");
         return;
     }
-    emit s->q_func()->panelAutoHideHideRequested();
+    Q_EMIT s->q_func()->panelAutoHideHideRequested();
 }
 
 void PlasmaShellSurfaceInterface::Private::panelAutoHideShowCallback(wl_client *client, wl_resource *resource)
@@ -296,7 +292,7 @@ void PlasmaShellSurfaceInterface::Private::panelAutoHideShowCallback(wl_client *
         wl_resource_post_error(s->resource, ORG_KDE_PLASMA_SURFACE_ERROR_PANEL_NOT_AUTO_HIDE, "Not an auto hide panel");
         return;
     }
-    emit s->q_func()->panelAutoHideShowRequested();
+    Q_EMIT s->q_func()->panelAutoHideShowRequested();
 }
 
 void PlasmaShellSurfaceInterface::Private::panelTakesFocusCallback(wl_client *client, wl_resource *resource, uint32_t takesFocus)
@@ -307,7 +303,7 @@ void PlasmaShellSurfaceInterface::Private::panelTakesFocusCallback(wl_client *cl
         return;
     }
     s->panelTakesFocus = takesFocus;
-    emit s->q_func()->panelTakesFocusChanged();
+    Q_EMIT s->q_func()->panelTakesFocusChanged();
 }
 
 void PlasmaShellSurfaceInterface::Private::setPanelBehavior(org_kde_plasma_surface_panel_behavior behavior)
@@ -332,7 +328,7 @@ void PlasmaShellSurfaceInterface::Private::setPanelBehavior(org_kde_plasma_surfa
     }
     m_panelBehavior = newBehavior;
     Q_Q(PlasmaShellSurfaceInterface);
-    emit q->panelBehaviorChanged();
+    Q_EMIT q->panelBehaviorChanged();
 }
 
 QPoint PlasmaShellSurfaceInterface::position() const
